@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef FILTERIMPORTERTESTUTIL_H
-#define FILTERIMPORTERTESTUTIL_H
+#pragma once
 
 #include <QString>
 
@@ -19,4 +18,3 @@ private:
     QString mFileName;
 };
 
-#endif // FILTERIMPORTERTESTUTIL_H
